<?php
    ini_set('memory_limit', '1024M');
    
    class Photos {
        private $extended_log = false;
        private $workdir = "";
        private $id = "";
        private $path_id = "";
        private $library_path = false;
        private $database_path = false;
        private $db_link = null;
        private $library_version = 4;
        
        public function __construct($workdir, $library_path, $uuid) {
            if ($i < 10) {
                $this->extended_log = true;
            }
            
            $this->workdir = trim($workdir);
            @mkdir($this->workdir."/export", 0777, true);
            
            $this->database_path = "/tmp/Library_tmp.apdb";
            
            if (!is_readable($this->database_path)) {
                echo "ERROR! Database does not exist.";
                die();
            }
            
            $this->path_id = str_replace("/", "_", $uuid);
            
            if (preg_match("/([A-Z0-9]{8}\-[A-Z0-9]{4}\-[A-Z0-9]{4}\-[A-Z0-9]{4}\-[A-Z0-9]{12})/", $uuid, $tmp)) {
                $uuid = $tmp[1];
            }
            
            $this->id = $uuid;
            
            $this->library_path = $library_path;
            
            $this->extract_keywords();
        }
        
        private function extract_keywords() {
            if ($this->connect_database()) {
                $keywords = array();
                
                if($this->library_version == "6"){
                    echo "6 (".$this->id.")\n";
                    $handle = $this->db_link->prepare('select * from ZASSET where ZUUID = ? limit 1');
                }elseif ($this->library_version == "5") {
                    echo "5 (".$this->id.")\n";
                    $handle = $this->db_link->prepare('select * from ZGENERICASSET where ZUUID = ? limit 1');
                }else{
                    return;
                }
                
                $handle->bindValue(1, $this->id);
                $handle->execute();
                
                $result = $handle->fetchAll(\PDO::FETCH_OBJ);
                
                if ($result) {
                    foreach($result as $row){
                        $z_pk = $row->Z_PK;
                        $tmp = 100*round($row->ZHIGHLIGHTVISIBILITYSCORE, 1);
                        $keywords[] = "HIGHLIGHT_VISIBILITY_SCORE_${tmp}";
                        $tmp = 100*round($row->ZOVERALLAESTETICSCORE, 1);
                        $keywords[] = "OVERALL_AESTETIC_SCORE_${tmp}";
                        
                        $subhandle = $this->db_link->prepare('select * from ZMEDIAANALYSISASSETATTRIBUTES where Z_PK = ? limit 1');
                        $subhandle->bindValue(1, $z_pk);
                        $subhandle->execute();
                        
                        $subresult = $subhandle->fetchAll(\PDO::FETCH_OBJ);
                        
                        if ($subresult) {
                            foreach($subresult as $subrow){
                                
                                $keywords[] = "FACE_COUNT_".$subrow->ZFACECOUNT;
                                $tmp = 100*round($subrow->ZBLURRINESSSCORE, 1);
                                $keywords[] = "BLURRINESS_SCORE_${tmp}";
                                $tmp = 100*round($subrow->ZEXPOSURESCORE, 1);
                                $keywords[] = "EXPOSURE_SCORE_${tmp}";
                            }
                        }
                        
                        var_dump($keywords);
                        echo "\nsave: ".$this->workdir."/export/".$this->path_id."\n";
                        
                        file_put_contents($this->workdir."/export/".$this->path_id,implode("\n", $keywords));
                    }
                }
            } else {
                echo "ERROR! failed to connect to database.";
                die();
            }
        }
        
        
        
        private function log($string) {
            if ($this->extended_log) {
                echo "LOG : ".$string."\n";
            }
        }
        
        private function connect_database() {
            try {
                $this->db_link = new \PDO("sqlite:".$this->database_path);
                
                $this->db_link->setAttribute(PDO::ATTR_ERRMODE,
                PDO::ERRMODE_EXCEPTION);
                
                $handle = $this->db_link->prepare('SELECT name FROM sqlite_master WHERE type=? AND name=?');
                $handle->bindValue(1, 'table');
                $handle->bindValue(2, 'ZGENERICASSET');
                
                $handle->execute();
                
                $result = $handle->fetchAll(\PDO::FETCH_OBJ);
                
                if ($result) {
                    $this->library_version = "5";
                }
            }
            catch(\PDOException $ex) {
                $this->log($ex->getMessage());
                return false;
            }
            
            try {
                $this->db_link = new \PDO("sqlite:".$this->database_path);
                
                $this->db_link->setAttribute(PDO::ATTR_ERRMODE,
                PDO::ERRMODE_EXCEPTION);
                
                $handle = $this->db_link->prepare('SELECT name FROM sqlite_master WHERE type=? AND name=?');
                $handle->bindValue(1, 'table');
                $handle->bindValue(2, 'ZASSET');
                
                $handle->execute();
                
                $result = $handle->fetchAll(\PDO::FETCH_OBJ);
                
                if ($result) {
                    $this->library_version = "6";
                }
            }
            catch(\PDOException $ex) {
                $this->log($ex->getMessage());
                return false;
            }
            
            return true;
        }
    }
    var_dump($argv);
    $Photos = new Photos($argv[1], $argv[2], $argv[3]);
